@@ -1690,21 +1690,22 @@ void qtractorTrack::drawTrack ( QPainter *pPainter, const QRect& trackRect,
 				iClipOffset += (iTrackStart - iClipStart);
 				iClipStart = iTrackStart;
 			}
-			if (iClipEnd > iTrackEnd) {
+			if (iClipEnd > iTrackEnd)
 				iClipEnd = iTrackEnd;
-			}
 			const int x1 = m_pSession->pixelFromFrame(iClipStart) - x0;
 			const int x2 = m_pSession->pixelFromFrame(iClipEnd) - x0;
-			pPainter->setPen(pen);
-			pPainter->setBrush(brush);
-			// Draw the clip...
-			const QRect clipRect(x1, y, x2 - x1, h);
-			pClip->drawClip(pPainter, clipRect, iClipOffset);
-			if (pClip == pClipRecordEx)
-				pPainter->fillRect(clipRect, QColor(255, 0, 0, 60));
-			else
-			if (pClip->isClipMute())
-				pPainter->fillRect(clipRect, QColor(0, 0, 0, 60));
+			if (x1 < x2) {
+				pPainter->setPen(pen);
+				pPainter->setBrush(brush);
+				// Draw the clip...
+				const QRect clipRect(x1, y, x2 - x1, h);
+				pClip->drawClip(pPainter, clipRect, iClipOffset);
+				if (pClip == pClipRecordEx)
+					pPainter->fillRect(clipRect, QColor(255, 0, 0, 60));
+				else
+				if (pClip->isClipMute())
+					pPainter->fillRect(clipRect, QColor(0, 0, 0, 60));
+			}
 		}
 		pClip = pClip->next();
 	}
